@@ -285,7 +285,6 @@ class MyForm(QtGui.QMainWindow):
     def cmdDown(self): sendCommand("108")
     def cmdLeft(self): sendCommand("105")
     def cmdRight(self): sendCommand("106")
-    def cmdExit(self): sendCommand("174")
     def cmdInfo(self): sendCommand("358")
     def cmdAudio(self): sendCommand("392")
     def cmdVideo(self): sendCommand("393")
@@ -306,6 +305,12 @@ class MyForm(QtGui.QMainWindow):
         if Mode =="E1":
             sendCommand("159")
     
+    def cmdExit(self): 
+        if Mode =="E2":
+            sendCommand("174")
+        if Mode =="E1":
+            sendCommand("1")
+
     def cmdprevious(self): 
         if Mode =="E2":
             sendCommand("412")
